#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_ELLINT_1_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_ELLINT_1_HPP_INCLUDED

#include <nt2/elliptic/include/functions/scalar/ellint_1.hpp>

#endif
